#pragma rtGlobals=1		// Use modern global access method.

//	*********************************************************************
//	* FormatTouchstonePlot
// 	* !!!! Works only with Touchstone File Loader, 
//  	* Improves aesthetics of selected touchstone graph
//	* Increases line width, assigns unique colors to each trace, adds legend, place x & y axis labels 
//	*********************************************************************
Menu "Macros"
	"FormatPlot", /Q, FormatPlot() //Adds button to menu
End

Function FormatPlot() 
	
	// initial string declerations	
	String traces
	String traceName
	String popStr
	String wavenme
	variable maxfreq
	variable pnts
	popStr="Rainbow16"	// Style of colors to be applied

	String graphName = WinName(0, 1) // Gets current graph name
	if (strlen(graphName) == 0)
		return -1
	endif

	Variable numTraces =KBTracesInGraph(graphName) // Gets number of traces in graph
	if (numTraces <= 0)
		return -1
	endif
	// Changes colors of traces
	Wave rgb= $KBColorTabWave(popStr)
	Variable numRows= DimSize(rgb,0)
	Variable red, green, blue
	Variable i, index
	if( numtraces <2)
		numTraces= 2	// avoid divide by zero, use just the first color for 1 trace
		for(i=0; i<numTraces; i+=1)
			index = round(i/(numTraces-1) * (numRows-1))	// spread entire color range over all traces.
			ModifyGraph rgb[i]=(rgb[index][0], rgb[index][1], rgb[index][2])
			break
		endfor
	else
		for(i=0; i<numTraces; i+=1)
			index = round(i/(numTraces-1) * (numRows-1))	// spread entire color range over all traces.
			ModifyGraph rgb[i]=(rgb[index][0], rgb[index][1], rgb[index][2])
		endfor
	endif
	
	Legend/C/N=text7/S=3/A=MC // Adds Legend	// removed by Alice Tsui

	// Gets name of trace and to help decide correct labels for x & y axis	
	traces=tracenamelist("",";",1) // gets string with all traces name, ";" seperated
	i=0
	traceName=""
	do
		traceName[i]=traces[i] // pulls off first trace name
		i+=1
	while(cmpstr(traces[i],";"))

	// Labels axis       
	if (CmpStr(traceName[strlen(traceName)-2]+traceName[strlen(traceName)-1],"dB")==0)
		//	if(cmpstr(traceName[1],"L")==0||cmpstr(traceName[1],"E")==0)	// modified by Alice Tsui
		Legend/C/N=text7/S=3/A=RB/x=0.00/y=0	// added by Alice Tsui
		Label left "\u#2Magnitude (dB)" // \u#2 removes units from axis
		Label bottom "\u#2Frequency (\U)"
		SetAxis left *,0
	elseif (CmpStr(traceName[strlen(traceName)-7]+traceName[strlen(traceName)-6]+traceName[strlen(traceName)-5]+traceName[strlen(traceName)-4]+traceName[strlen(traceName)-3]+traceName[strlen(traceName)-2]+traceName[strlen(traceName)-1],"DB_smth")==0)
		Legend/C/N=text7/S=3/A=RT/x=0.00/y=0	// added by Alice tsui
		Label left "\u#2Magnitude (dB)" // \u#2 removes units from axis
		Label bottom "\u#2Frequency (\U)"
		SetAxis left *,0
	elseif(CmpStr(traceName[strlen(traceName)-2]+traceName[strlen(traceName)-1],"_A")==0)
		Legend/C/N=text7/S=3/A=RB/x=0.00/y=0	// added by Alice Tsui
		Label left "\u#2Phase (Degrees)"
		Label bottom "\u#2Frequency (\U)"
	elseif (CmpStr(traceName[strlen(traceName)-6]+traceName[strlen(traceName)-5]+traceName[strlen(traceName)-4]+traceName[strlen(traceName)-3]+traceName[strlen(traceName)-2]+traceName[strlen(traceName)-1],"A_smth")==0)
		Legend/C/N=text7/S=3/A=RT/x=0.00/y=0	// added by Alice Tsui
		Label left "\u#2Phase (Degrees)"
		Label bottom "\u#2Frequency (\U)"
	elseif(cmpstr(traceName[0,1],"z_")==0)	// this elseif section is added by Alice Tsui
		Legend/C/N=text7/S=3/A=RT/x=0.00/y=0
		setscale/p d 0,0,"",$traceName
		setscale/p d 0,0,"s",waverefindexed("",0,2)
		Label left "\u#2Impedance (\U)"
		Label bottom "\u#2Time (\U)"
		setaxis left 80,150
		modifygraph grid=1
	elseif(cmpstr(traceName[0,1],"u_")==0)	// this elseif section added by Alice Tsui
		legend/c/n=text7/s=3/a=lt/x=0.00/y=0
		label left "\u#2Unit \U"
		setscale/p d 0,0,"s",waverefindexed("",0,2)
		label bottom "\u#2Time (\U)"
	elseif(cmpstr(traceName[strlen(traceName)-3,strlen(traceName)-1],"_GD")==0) // Adds group delay label, modified by Alice Tsui
		wave unitwave=$tracename
		string units=""
		units="s"
		SetScale /P d 0, 0, units, unitwave
		Legend/C/N=text7/S=3/A=RT
		Label left "Group Delay (\U)"
		Label bottom "\u#2Frequency (\U)"
	else		// Add by Alice Tsui
		//	SetAxis left 0,*

		Legend/C/N=text7/S=3/A=mt
		Label left "\u#2Magnitude (dB)"
		Label bottom "\u#2Frequency (GHz)"
	
	endif
	
	// Modifies graph properties for improved looks
	TextBox/C/N=title/F=0/A=MT/X=0.00/Y=0/E "\Zr125Title"
	ModifyGraph  lSize=2
	ModifyGraph axThick=1
	ModifyGraph fStyle=1
	modifygraph minor=1	// added by Alice Tsui
	modifygraph grid=1	// added by Alice Tsui
End

static Function KBTracesInGraph(win)	// "" for top graph
	String win
	
	if( strlen(win) == 0 )
		win= WinName(0,1)
		if( strlen(win) == 0 )
			return 0
		endif
	endif
	return ItemsInList(TraceNameList(win,";",3))
End

static Function/S KBColorTabWave(ctabName)
	String ctabName
	
	String savedDataFolder= GetDatafolder(1)
	NewDataFolder/O/S root:Packages
	NewDataFolder/O/S :KBColorize

	ColorTab2Wave $ctabname	// creates M_colors
	Wave M_colors
	SetDataFolder savedDataFolder
	return GetWavesDataFolder(M_colors,2)
End