#pragma rtGlobals=1
#pragma version=6.01
#pragma IgorVersion=6		// requires Igor 6 (StatsMedian)

//	*********************************************************************
//	* SingletoDiff
//  * Creates pop dialog for user to assign ports
//	* Converts single-ended 4 port S-parameters to 2 port differential
//  * Eg:
//				1	---|	DUT	|---   3		------>    1 ---| DUT| --- 2
//				2	---|			|---   4
//  * Converts all dB and Angle waves loaded 
// 	* Names of converted waves are same as original, but with "d" appeneded after S11, S12, etc
// 	* For conversion theory, see "Mixed-mode S-parameter characterization of differential structures"
// 	*   authors: W Fan, A Lu, LL Wai, BK Lok
// 	* Must be used in conjuction with Touchstone_File_Loader.ipf 
//	*********************************************************************

Menu "Analysis"
	"Single_4-Port_to_Diff_2-port", Single2Diff() // Adds button to menu
	"DiffAll",diffall()
End

function diffall()
	string folder
	dfref df = getdatafolderdfr()
	variable i=0
	do
		folder = getindexedobjnamedfr(df,4,i)
		setdatafolder df
		setdatafolder $folder
		Single2Diff()
		i+=1
	while(cmpstr(folder,""))
end

Function Single2Diff()


	variable i=0 //in use
	variable j=0 // in use 
	variable k=0 // in use
	variable m=0 // in use
	variable too_few=1
	variable n=0
	variable p=0


	variable pnts=0 // in use
	variable a=1 // in use
	variable test1
	variable test2
	string Snamew

	//// creates prompt for user to chose wave to perform conversion on
	//Prompt Snamew,"Select a wave to peform conversion on:", popup, WaveList("*",";","")
	//DoPrompt "Single_to_Diff Conversion", Snamew
	//	if (V_flag)
	//		return NaN
	//	endif
	//	pnts=numpnts($Snamew) // find out number of pnts in frequency wave
	//
	//	
	//// creates prompt to allow user to define ports	
	//NewPanel/K=1 /N=Port_Configuration/W=(512,151,780,280)
	//	
	//	// illustrate a default box
	//TitleBox  tb0, fsize=14 ,frame=0,title="Assign Physical Port Numbers",pos={40,13}	
	//	// illustrate a default box
	//TitleBox tb1,frame=0,title="\r----|---------------|----\r     |     DUT      |\r----|---------------|----\r",pos={140,100}
	//
	//// Move center to 150,100
	//TitleBox tb1,pos={133,65},size={0,0},anchor=MC
	//
	//	string /G port1="0"
	//	string /G port2="0"
	//	string /G port3="0"
	//	string /G port4="0"
	//	SetVariable setvarnpts1,pos={50,47},size={30,15},limits={0,1000,0},value=port1,title="1 "
	//	SetVariable setvarnpts2,pos={190,47},size={30,15},limits={0,1000,0},value=port2,title="2 "
	//	SetVariable setvarnpts3,pos={50,72},size={30,15},limits={0,1000,0},value=port3,title="3 "
	//	SetVariable setvarnpts4,pos={190,72},size={30,15},limits={0,1000,0},value=port4,title="4 "
	//	
	//	
	//	
	//Button buttonDefault,pos={145,96},size={63,20},proc=closewin,title="Enter"
	//Button exit,pos={65,96},size={63,20},proc=exitwin,title="Cancel"
	//pauseforuser Port_Configuration
	//if(cmpstr(port1,"0")==0 && cmpstr(port2,"0")==0 &&cmpstr(port3,"0")==0  && cmpstr(port4,"0")==0 )
	//return 0
	//endif

	// modified by Alice Tsui
	Snamew = WaveName("",0,4)  
	pnts=numpnts($Snamew) // find out number of pnts in frequency wave
	string /G port1="1"
	string /G port2="2"
	string /G port3="3"
	string /G port4="4"


	Make/O/C/N=(4,4) Smat		// Initialize S-Matrix to be populated

	// Count how many waves are loaded into Igor
	do
		wave Sname=WaveRefIndexed("",i,4)  
		string nameb=NameOfWave(Sname)
		if(cmpstr(nameb,"")==0)
			a=0
		endif
		i+=1
	while(a)

	k=i  // k now contains the number of total waves in root directory
	i=0

	// initialize temp waves
	make/O/N=(pnts) s11,s12,s13,s14,s21,s22,s23,s24,s31,s32,s33,s34,s41,s42,s43,s44,s11dA,s12dA,s13dA,s14dA,s21dA,s22dA,s23dA,s24dA,s31dA,s32dA,s33dA,s34dA,s41dA,s42dA,s43dA,s44dA
	make/O/C/N=(pnts) s11p,s12p,s13p,s14p,s21p,s22p,s23p,s24p,s31p,s32p,s33p,s34p,s41p,s42p,s43p,s44p
	make/O/C/N=(pnts) s11t,s12t,s13t,s14t,s21t,s22t,s23t,s24t,s31t,s32t,s33t,s34t,s41t,s42t,s43t,s44t


	// loop looks for waves ending in dB or A, then performs the single to differential conversion 
	do

		wave Sname=WaveRefIndexed("",i,4)

		string name=NameOfWave(Sname)
		string namew=""
		string namep=""
		do
			namep[p]=Snamew[p]
			namew[p]=name[p]
			p+=1
		while(p<strlen(name)-8)
		p=0
		if (cmpstr(namep,namew)==0)
			if (cmpstr(name[strlen(name)-6,strlen(name)-1],"S11_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S11 // duplicate orginal wave so that we can manipulate the data
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S11A  // duplicate orginal wave so that we can manipulate the data
				S11A=pi*(S11A/180) // convert angle wave to radians
				s11=10^(s11/20) // convert magnitude wave to linear scale
				s11p=cmplx(S11,S11A) // store magnitude and angle in complex wave
				s11p=p2rect(s11p) // convert complex wave from polar to rectangular form 

				string temp_name=NameOfWave(WaveRefIndexed("",i,4)) // create name of wave that will hold the converted S-param data
				string title=""
				n=0
				do 
					title[n]=temp_name[n]
					n+=1
				while(cmpstr(temp_name[n]+temp_name[n+1]+temp_name[n+2]+temp_name[n+3],"_S11"))
				//title=title[0]+title[1]+title[2]+title[3]+title[4]+title[5]+title[6]+title[7]+title[8]+title[9]+title[10]+title[11]+title[12]+title[13]+title[14]

				string wave1=title+"_Sdd11_DB"
				string wave2=title+"_Sdd12_DB"
				string wave3=title+"_Sdc11_DB"
				string wave4=title+"_Sdc12_DB"
				string wave5=title+"_Sdd21_DB"
				string wave6=title+"_Sdd22_DB"
				string wave7=title+"_Sdc21_DB"
				string wave8=title+"_Sdc22_DB"
				string wave9=title+"_Scd11_DB"
				string wave10=title+"_Scd12_DB"
				string wave11=title+"_Scc11_DB"
				string wave12=title+"_Scc12_DB"
				string wave13=title+"_Scd21_DB"
				string wave14=title+"_Scd22_DB"
				string wave15=title+"_Scc21_DB"
				string wave16=title+"_Scc22_DB"
				string wave1a=title+"_Sdd11_A"
				string wave2a=title+"_Sdd12_A"
				string wave3a=title+"_Sdc11_A"
				string wave4a=title+"_Sdc12_A"
				string wave5a=title+"_Sdd21_A"
				string wave6a=title+"_Sdd22_A"
				string wave7a=title+"_Sdc21_A"
				string wave8a=title+"_Sdc22_A"
				string wave9a=title+"_Scd11_A"
				string wave10a=title+"_Scd12_A"
				string wave11a=title+"_Scc11_A"
				string wave12a=title+"_Scc12_A"
				string wave13a=title+"_Scd21_A"
				string wave14a=title+"_Scd22_A"
				string wave15a=title+"_Scc21_A"
				string wave16a=title+"_Scc22_A"



			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S12_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S12
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S12A
				S12A=pi*(S12A/180)
				s12=10^(s12/20)
				s12p=cmplx(S12,S12A)
				s12p=p2rect(s12p)


			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S13_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S13
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S13A
				S13A=pi*(S13A/180)
				s13=10^(s13/20)
				s13p=cmplx(S13,S13A)
				s13p=p2rect(s13p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S14_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S14
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S14A
				S14A=pi*(S14A/180)
				s14=10^(s14/20)
				s14p=cmplx(S14,S14A)
				s14p=p2rect(s14p)
				too_few=0
				// initialize temp waves
				make/O/N=(pnts) $wave1,$wave2,$wave3,$wave4,$wave5,$wave6,$wave7,$wave8,$wave9,$wave10,$wave11,$wave12,$wave13,$wave14,$wave15,$wave16
				wave w1=$wave1,w2=$wave2,w3=$wave3,w4=$wave4,w5=$wave5,w6=$wave6,w7=$wave7,w8=$wave8,w9=$wave9,w10=$wave10,w11=$wave11,w12=$wave12,w13=$wave13,w14=$wave14,w15=$wave15,w16=$wave16
				make/O/N=(pnts) $wave1a,$wave2a,$wave3a,$wave4a,$wave5a,$wave6a,$wave7a,$wave8a,$wave9a,$wave10a,$wave11a,$wave12a,$wave13a,$wave14a,$wave15a,$wave16a
				wave w1a=$wave1a,w2a=$wave2a,w3a=$wave3a,w4a=$wave4a,w5a=$wave5a,w6a=$wave6a,w7a=$wave7a,w8a=$wave8a,w9a=$wave9a,w10a=$wave10a,w11a=$wave11a,w12a=$wave12a,w13a=$wave13a,w14a=$wave14a,w15a=$wave15a,w16a=$wave16a


			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S21_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S21
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S21A
				S21A=pi*(S21A/180)
				s21=10^(s21/20)
				s21p=cmplx(S21,S21A)
				s21p=p2rect(s21p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S22_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S22
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S22A
				S22A=pi*(S22A/180)
				s22=10^(s22/20)
				s22p=cmplx(S22,S22A)
				s22p=p2rect(s22p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S23_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S23
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S23A
				S23A=pi*(S23A/180)
				s23=10^(s23/20)
				s23p=cmplx(S23,S23A)
				s23p=p2rect(s23p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S24_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S24
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S24A
				S24A=pi*(S24A/180)
				s24=10^(s24/20)
				s24p=cmplx(S24,S24A)
				s24p=p2rect(s24p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S31_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S31
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S31A
				S31A=pi*(S31A/180)
				s31=10^(s31/20)
				s31p=cmplx(S31,S31A)
				s31p=p2rect(s31p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S32_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S32
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S32A
				S32A=pi*(S32A/180)
				s32=10^(s32/20)
				s32p=cmplx(S32,S32A)
				s32p=p2rect(s32p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S33_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S33
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S33A
				S33A=pi*(S33A/180)
				s33=10^(s33/20)
				s33p=cmplx(S33,S33A)
				s33p=p2rect(s33p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S34_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S34
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S34A
				S34A=pi*(S34A/180)
				s34=10^(s34/20)
				s34p=cmplx(S34,S34A)
				s34p=p2rect(s34p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S41_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S41
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S41A
				S41A=pi*(S41A/180)
				s41=10^(s41/20)
				s41p=cmplx(S41,S41A)
				s41p=p2rect(s41p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S42_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S42
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S42A
				S42A=pi*(S42A/180)
				s42=10^(s42/20)
				s42p=cmplx(S42,S42A)
				s42p=p2rect(s42p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S43_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S43
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S43A
				S43A=pi*(S43A/180)
				s43=10^(s43/20)
				s43p=cmplx(S43,S43A)
				s43p=p2rect(s43p)

			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S44_DB")==0)
				Duplicate/O WaveRefIndexed("",i,4),S44
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S44A
				S44A=pi*(S44A/180)
				s44=10^(s44/20)
				s44p=cmplx(S44,S44A)
				s44p=p2rect(s44p)
				m=1

			endif

			if (cmpstr(name[strlen(name)-4,strlen(name)-1],"S11_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S11 // duplicate orginal wave so that we can manipulate the data
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S11A  // duplicate orginal wave so that we can manipulate the data
				s11p=cmplx(S11,S11A) // store real and imaginary part in complex wave


				temp_name=NameOfWave(WaveRefIndexed("",i,4)) // create name of wave that will hold the converted S-param data
				title=""
				n=0
				do 
					title[n]=temp_name[n]
					n+=1
				while(cmpstr(temp_name[n]+temp_name[n+1]+temp_name[n+2]+temp_name[n+3],"_S11"))
				//title=title[0]+title[1]+title[2]+title[3]+title[4]+title[5]+title[6]+title[7]+title[8]+title[9]+title[10]+title[11]+title[12]+title[13]+title[14]

				wave1=title+"_S11dd_DB"
				wave2=title+"_S12dd_DB"
				wave3=title+"_S11dc_DB"
				wave4=title+"_S12dc_DB"
				wave5=title+"_S21dd_DB"
				wave6=title+"_S22dd_DB"
				wave7=title+"_S21dc_DB"
				wave8=title+"_S22dc_DB"
				wave9=title+"_S11cd_DB"
				wave10=title+"_S12cd_DB"
				wave11=title+"_S11cc_DB"
				wave12=title+"_S12cc_DB"
				wave13=title+"_S21cd_DB"
				wave14=title+"_S22cd_DB"
				wave15=title+"_S21cc_DB"
				wave16=title+"_S22cc_DB"
				wave1a=title+"_S11dd_A"
				wave2a=title+"_S12dd_A"
				wave3a=title+"_S11dc_A"
				wave4a=title+"_S12dc_A"
				wave5a=title+"_S21dd_A"
				wave6a=title+"_S22dd_A"
				wave7a=title+"_S21dc_A"
				wave8a=title+"_S22dc_A"
				wave9a=title+"_S11cd_A"
				wave10a=title+"_S12cd_A"
				wave11a=title+"_S11cc_A"
				wave12a=title+"_S12cc_A"
				wave13a=title+"_S21cd_A"
				wave14a=title+"_S22cd_A"
				wave15a=title+"_S21cc_A"
				wave16a=title+"_S22cc_A"



			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S12_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S12
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S12A

				s12p=cmplx(S12,S12A)



			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S13_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S13
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S13A

				s13p=cmplx(S13,S13A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S14_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S14
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S14A

				s14p=cmplx(S14,S14A)

				too_few=0
				// initialize temp waves
				make/O/N=(pnts) $wave1,$wave2,$wave3,$wave4,$wave5,$wave6,$wave7,$wave8,$wave9,$wave10,$wave11,$wave12,$wave13,$wave14,$wave15,$wave16
				wave w1=$wave1,w2=$wave2,w3=$wave3,w4=$wave4,w5=$wave5,w6=$wave6,w7=$wave7,w8=$wave8,w9=$wave9,w10=$wave10,w11=$wave11,w12=$wave12,w13=$wave13,w14=$wave14,w15=$wave15,w16=$wave16
				make/O/N=(pnts) $wave1a,$wave2a,$wave3a,$wave4a,$wave5a,$wave6a,$wave7a,$wave8a,$wave9a,$wave10a,$wave11a,$wave12a,$wave13a,$wave14a,$wave15a,$wave16a
				wave w1a=$wave1a,w2a=$wave2a,w3a=$wave3a,w4a=$wave4a,w5a=$wave5a,w6a=$wave6a,w7a=$wave7a,w8a=$wave8a,w9a=$wave9a,w10a=$wave10a,w11a=$wave11a,w12a=$wave12a,w13a=$wave13a,w14a=$wave14a,w15a=$wave15a,w16a=$wave16a


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S21_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S21
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S21A

				s21p=cmplx(S21,S21A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S22_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S22
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S22A

				s22p=cmplx(S22,S22A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S23_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S23
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S23A

				s23p=cmplx(S23,S23A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S24_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S24
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S24A

				s24p=cmplx(S24,S24A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S31_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S31
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S31A

				s31p=cmplx(S31,S31A)


			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S32_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S32
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S32A

				s32p=cmplx(S32,S32A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S33_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S33
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S33A

				s33p=cmplx(S33,S33A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S34_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S34
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S34A

				s34p=cmplx(S34,S34A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S41_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S41
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S41A

				s41p=cmplx(S41,S41A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S42_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S42
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S42A

				s42p=cmplx(S42,S42A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S43_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S43
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S43A

				s43p=cmplx(S43,S43A)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S44_R")==0)
				Duplicate/O WaveRefIndexed("",i,4),S44
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S44A
				s44p=cmplx(S44,S44A)

				m=1


			endif
			if (cmpstr(name[strlen(name)-4,strlen(name)-1],"S11_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S11 // duplicate orginal wave so that we can manipulate the data
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S11A  // duplicate orginal wave so that we can manipulate the data
				S11A=pi*(S11A/180) // convert to radians
				s11p=cmplx(S11,S11A) // store real and imaginary part in complex wave
				s11p=p2rect(s11p) // convert to rect form

				temp_name=NameOfWave(WaveRefIndexed("",i,4)) // create name of wave that will hold the converted S-param data
				title=""
				n=0
				do 
					title[n]=temp_name[n]
					n+=1
				while(cmpstr(temp_name[n]+temp_name[n+1]+temp_name[n+2]+temp_name[n+3],"_S11"))
				//title=title[0]+title[1]+title[2]+title[3]+title[4]+title[5]+title[6]+title[7]+title[8]+title[9]+title[10]+title[11]+title[12]+title[13]+title[14]

				wave1=title+"_S11dd_DB"
				wave2=title+"_S12dd_DB"
				wave3=title+"_S11dc_DB"
				wave4=title+"_S12dc_DB"
				wave5=title+"_S21dd_DB"
				wave6=title+"_S22dd_DB"
				wave7=title+"_S21dc_DB"
				wave8=title+"_S22dc_DB"
				wave9=title+"_S11cd_DB"
				wave10=title+"_S12cd_DB"
				wave11=title+"_S11cc_DB"
				wave12=title+"_S12cc_DB"
				wave13=title+"_S21cd_DB"
				wave14=title+"_S22cd_DB"
				wave15=title+"_S21cc_DB"
				wave16=title+"_S22cc_DB"
				wave1a=title+"_S11dd_A"
				wave2a=title+"_S12dd_A"
				wave3a=title+"_S11dc_A"
				wave4a=title+"_S12dc_A"
				wave5a=title+"_S21dd_A"
				wave6a=title+"_S22dd_A"
				wave7a=title+"_S21dc_A"
				wave8a=title+"_S22dc_A"
				wave9a=title+"_S11cd_A"
				wave10a=title+"_S12cd_A"
				wave11a=title+"_S11cc_A"
				wave12a=title+"_S12cc_A"
				wave13a=title+"_S21cd_A"
				wave14a=title+"_S22cd_A"
				wave15a=title+"_S21cc_A"
				wave16a=title+"_S22cc_A"



			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S12_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S12
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S12A

				S12A=pi*(S12A/180)
				s12p=cmplx(S12,S12A) 
				s12p=p2rect(s12p) 



			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S13_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S13
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S13A

				S13A=pi*(S13A/180)
				s13p=cmplx(S13,S13A) 
				s13p=p2rect(s13p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S14_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S14
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S14A

				S14A=pi*(S14A/180)
				s14p=cmplx(S14,S14A) 
				s14p=p2rect(s14p)

				too_few=0
				// initialize temp waves
				make/O/N=(pnts) $wave1,$wave2,$wave3,$wave4,$wave5,$wave6,$wave7,$wave8,$wave9,$wave10,$wave11,$wave12,$wave13,$wave14,$wave15,$wave16
				wave w1=$wave1,w2=$wave2,w3=$wave3,w4=$wave4,w5=$wave5,w6=$wave6,w7=$wave7,w8=$wave8,w9=$wave9,w10=$wave10,w11=$wave11,w12=$wave12,w13=$wave13,w14=$wave14,w15=$wave15,w16=$wave16
				make/O/N=(pnts) $wave1a,$wave2a,$wave3a,$wave4a,$wave5a,$wave6a,$wave7a,$wave8a,$wave9a,$wave10a,$wave11a,$wave12a,$wave13a,$wave14a,$wave15a,$wave16a
				wave w1a=$wave1a,w2a=$wave2a,w3a=$wave3a,w4a=$wave4a,w5a=$wave5a,w6a=$wave6a,w7a=$wave7a,w8a=$wave8a,w9a=$wave9a,w10a=$wave10a,w11a=$wave11a,w12a=$wave12a,w13a=$wave13a,w14a=$wave14a,w15a=$wave15a,w16a=$wave16a


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S21_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S21
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S21A

				S21A=pi*(S21A/180)
				s21p=cmplx(S21,S21A) 
				s21p=p2rect(s21p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S22_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S22
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S22A

				S22A=pi*(S22A/180)
				s22p=cmplx(S22,S22A) 
				s22p=p2rect(s22p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S23_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S23
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S23A

				S23A=pi*(S23A/180)
				s23p=cmplx(S23,S23A) 
				s23p=p2rect(s23p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S24_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S24
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S24A

				S24A=pi*(S24A/180)
				s24p=cmplx(S24,S24A) 
				s24p=p2rect(s24p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S31_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S31
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S31A

				S31A=pi*(S31A/180)
				s31p=cmplx(S31,S31A) 
				s31p=p2rect(s31p)


			elseif (cmpstr(name[strlen(name)-6,strlen(name)-1],"S32_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S32
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S32A

				S32A=pi*(S32A/180)
				s32p=cmplx(S32,S32A) 
				s32p=p2rect(s32p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S33_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S33
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S33A

				S33A=pi*(S33A/180)
				s33p=cmplx(S33,S33A) 
				s33p=p2rect(s33p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S34_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S34
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S34A

				S34A=pi*(S34A/180)
				s34p=cmplx(S34,S34A) 
				s34p=p2rect(s34p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S41_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S41
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S41A

				S41A=pi*(S41A/180)
				s41p=cmplx(S41,S41A) 
				s41p=p2rect(s41p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S42_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S42
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S42A

				S42A=pi*(S42A/180)
				s42p=cmplx(S42,S42A) 
				s42p=p2rect(s42p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S43_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S43
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S43A

				S43A=pi*(S43A/180)
				s43p=cmplx(S43,S43A) 
				s43p=p2rect(s43p)


			elseif (cmpstr(name[strlen(name)-4,strlen(name)-1],"S44_M")==0)
				Duplicate/O WaveRefIndexed("",i,4),S44
				i+=1
				Duplicate/O WaveRefIndexed("",i,4),S44A
				S44A=pi*(S44A/180)
				s44p=cmplx(S44,S44A) 
				s44p=p2rect(s44p)

				m=1


			endif


			// store imported s-params in temp waves
			duplicate /C/O s11p,s11t
			duplicate /C/O s12p,s12t
			duplicate /C/O s13p,s13t
			duplicate /C/O s14p,s14t
			duplicate /C/O s21p,s21t
			duplicate /C/O s22p,s22t
			duplicate /C/O s23p,s23t
			duplicate /C/O s24p,s24t
			duplicate /C/O s31p,s31t
			duplicate /C/O s32p,s32t
			duplicate /C/O s33p,s33t
			duplicate /C/O s34p,s34t
			duplicate /C/O s41p,s41t
			duplicate /C/O s42p,s42t
			duplicate /C/O s43p,s43t
			duplicate /C/O s44p,s44t

			// re-map user imported s-params to ports to 1 <-> 2 / 3 <->4
			string s11p_s
			string s12p_s
			string s13p_s
			string s14p_s
			string s21p_s
			string s22p_s
			string s23p_s
			string s24p_s
			string s31p_s
			string s32p_s
			string s33p_s
			string s34p_s
			string s41p_s
			string s42p_s
			string s43p_s
			string s44p_s
			s11p_s="s"+port1+port1+"t"
			s12p_s="s"+port1+port2+"t"
			s13p_s="s"+port1+port3+"t"
			s14p_s="s"+port1+port4+"t"
			s21p_s="s"+port2+port1+"t"
			s22p_s="s"+port2+port2+"t"
			s23p_s="s"+port2+port3+"t"
			s24p_s="s"+port2+port4+"t"
			s31p_s="s"+port3+port1+"t"
			s32p_s="s"+port3+port2+"t"
			s33p_s="s"+port3+port3+"t"
			s34p_s="s"+port3+port4+"t"
			s41p_s="s"+port4+port1+"t"
			s42p_s="s"+port4+port2+"t"
			s43p_s="s"+port4+port3+"t"
			s44p_s="s"+port4+port4+"t"
			duplicate /C/O $s11p_s,s11p
			duplicate /C/O $s12p_s,s12p
			duplicate /C/O $s13p_s,s13p
			duplicate /C/O $s14p_s,s14p
			duplicate /C/O $s21p_s,s21p
			duplicate /C/O $s22p_s,s22p
			duplicate /C/O $s23p_s,s23p
			duplicate /C/O $s24p_s,s24p
			duplicate /C/O $s31p_s,s31p
			duplicate /C/O $s32p_s,s32p
			duplicate /C/O $s33p_s,s33p
			duplicate /C/O $s34p_s,s34p
			duplicate /C/O $s41p_s,s41p
			duplicate /C/O $s42p_s,s42p
			duplicate /C/O $s43p_s,s43p
			duplicate /C/O $s44p_s,s44p


			if(m==1 && too_few==0)
				do
					// Performs matrix math to convert single to diff 
					Smat[0][0]=s11p[j]-s13p[j]-s31p[j]+s33p[j]
					Smat[0][1]=s12p[j]-s14p[j]-s32p[j]+s34p[j]
					Smat[1][0]=s21p[j]-s23p[j]-s41p[j]+s43p[j]
					Smat[1][1]=s22p[j]-s24p[j]-s42p[j]+s44p[j]
					Smat[2][0]=s11p[j]-s13p[j]+s31p[j]-s33p[j]
					Smat[2][1]=s12p[j]-s14p[j]+s32p[j]-s34p[j]
					Smat[3][0]=s21p[j]-s23p[j]+s41p[j]-s43p[j]
					Smat[3][1]=s22p[j]-s24p[j]+s42p[j]-s44p[j]
					Smat[0][2]=s11p[j]+s13p[j]-s31p[j]-s33p[j]
					Smat[0][3]=s12p[j]+s14p[j]-s32p[j]-s34p[j]
					Smat[1][2]=s21p[j]+s23p[j]-s41p[j]-s43p[j]
					Smat[1][3]=s22p[j]+s24p[j]-s42p[j]-s44p[j]
					Smat[2][2]=s11p[j]+s13p[j]+s31p[j]+s33p[j]
					Smat[2][3]=s12p[j]+s14p[j]+s32p[j]+s34p[j]
					Smat[3][2]=s21p[j]+s23p[j]+s41p[j]+s43p[j]
					Smat[3][3]=s22p[j]+s24p[j]+s42p[j]+s44p[j]
					Smat=Smat*0.5
					Smat=r2polar(Smat) // converts output wave back to polar form

					// converts outputs waves back to dB and degrees
					w1[j]=20*log(real(Smat[0][0]))
					w1a[j]=180*(imag(Smat[0][0])/pi)
					w2[j]=20*log(real(Smat[0][1]))
					w2a[j]=180*(imag(Smat[0][1])/pi)
					w3[j]=20*log(real(Smat[0][2]))
					w3a[j]=180*(imag(Smat[0][2])/pi)
					w4[j]=20*log(real(Smat[0][3]))
					w4a[j]=180*(imag(Smat[0][3])/pi)
					w5[j]=20*log(real(Smat[1][0]))
					w5a[j]=180*(imag(Smat[1][0])/pi)
					w6[j]=20*log(real(Smat[1][1]))
					w6a[j]=180*(imag(Smat[1][1])/pi)
					w7[j]=20*log(real(Smat[1][2]))
					w7a[j]=180*(imag(Smat[1][2])/pi)
					w8[j]=20*log(real(Smat[1][3]))
					w8a[j]=180*(imag(Smat[1][3])/pi)
					w9[j]=20*log(real(Smat[2][0]))
					w9a[j]=180*(imag(Smat[2][0])/pi)
					w10[j]=20*log(real(Smat[2][1]))
					w10a[j]=180*(imag(Smat[2][1])/pi)
					w11[j]=20*log(real(Smat[2][2]))
					w11a[j]=180*(imag(Smat[2][2])/pi)
					w12[j]=20*log(real(Smat[2][3]))
					w12a[j]=180*(imag(Smat[2][3])/pi)
					w13[j]=20*log(real(Smat[3][0]))
					w13a[j]=180*(imag(Smat[3][0])/pi)
					w14[j]=20*log(real(Smat[3][1]))
					w14a[j]=180*(imag(Smat[3][1])/pi)
					w15[j]=20*log(real(Smat[3][2]))
					w15a[j]=180*(imag(Smat[3][2])/pi)
					w16[j]=20*log(real(Smat[3][3]))
					w16a[j]=180*(imag(Smat[3][3])/pi)
					j+=1

				while(j<pnts)
				m=0
				j=0
			endif
		endif

		i+=1
	while(i<k)

	// removes temp waves
	KillWaves s11,s12,s13,s14,s21,s22,s23,s24,s31,s32,s33,s34,s41,s42,s43,s44,s11p,s12p,s13p,s14p,s21p,s22p,s23p,s24p,s31p,s32p,s33p,s34p,s41p,s42p,s43p,s44p,Smat,s11dA,s12dA,s13dA,s14dA,s21dA,s22dA,s23dA,s24dA,s31dA,s32dA,s33dA,s34dA,s41dA,s42dA,s43dA,s44dA,s11a,s12a,s13a,s14a,s21a,s22a,s23a,s24a,s31a,s32a,s33a,s34a,s41a,s42a,s43a,s44a
	KillWaves s11t,s12t,s13t,s14t,s21t,s22t,s23t,s24t,s31t,s32t,s33t,s34t,s41t,s42t,s43t,s44t
End


// Close popup when Enter or Cancel button are clicked
Function closewin (buttonDefault) : ButtonControl
	String buttonDefault
	DoWindow /K Port_Configuration
	
End

Function exitwin (exit) : ButtonControl
	String exit
	DoWindow /K Port_Configuration
	
End

